%bcond test_example 1

Name:           python-cmake-build-extension
Version:        0.6.0
Release:    1%{?dist}
Summary:        Setuptools extension to build and package CMake projects

License:        MIT AND BSD-3-Clause
URL:            https://github.com/diegoferigo/cmake-build-extension
Source0:         %{pypi_source cmake_build_extension}

BuildArch:      noarch

BuildRequires:  python3-devel
BuildRequires:  cmake
BuildRequires:  ninja-build

%if %{with test_example}
BuildRequires:  gcc
BuildRequires:  gcc-c++

BuildRequires:  swig
BuildRequires:  cmake(pybind11)
BuildRequires:  cmake(Eigen3)

BuildRequires:  python3dist(pytest)
%endif

%global common_description %{expand:
This project aims to simplify the integration of C++ projects based on CMake
with Python packaging tools. CMake provides out-of-the-box support to either
SWIG and pybind11, that are two among the most used projects to create Python
bindings from C++ sources.

If you have any experience with these hybrid projects, you know the challenges
to make packaging right! This project takes inspiration from pre-existing
examples (pybind/cmake_example, among many others) and provides a simple,
flexible, and reusable setuptools extension with the following features:

  • Bridge between CMake projects and Python packaging.
  • Configure and build the CMake project from setup.py.
  • Install the CMake project in the resulting Python package.
  • Allow passing custom CMake options.
  • Allow creating a top-level __init__.py.
  • Expose C++ executables to the Python environment.
  • Provide a context manager to import reliably CPython modules on all major
    OSs.
  • Disable the C++ extension in editable installations (requiring to manually
    call CMake to install the C++ project).}

%description %{common_description}


%package -n python3-cmake-build-extension
Summary:        %{summary}

License:        MIT

Requires:       cmake
Requires:       ninja-build

%description -n python3-cmake-build-extension %{common_description}


%package -n python3-cmake-build-extension-doc
Summary:        Documentation and examples for cmake-build-extension

Requires:       python3-cmake-build-extension = %{version}-%{release}

%description -n python3-cmake-build-extension-doc %{common_description}


%prep
%autosetup -n cmake_build_extension-%{version} -p1

sed -r -i '/^[[:blank:]]*\b(cmake|ninja)\b[[:blank:]]*$/d' setup.cfg

%if %{with test_example}
cp -rp example test_example
%endif


%generate_buildrequires
%pyproject_buildrequires
%if %{with test_example}
(
  cd test_example >/dev/null
  %pyproject_buildrequires
) | grep -Ev 'cmake-build-extension'
%endif


%build
%pyproject_wheel


%install
%pyproject_install
%pyproject_save_files cmake_build_extension


%check

%if %{with test_example}
pushd test_example >/dev/null
export PYTHONPATH='%{buildroot}%{python3_sitelib}'
%pyproject_wheel

BLIB="${PWD}/build/lib.%{python3_platform}-cpython-%{python3_version_nodots}"
export PYTHONPATH="${PYTHONPATH}:${BLIB}"
export PATH="${PATH}:${BLIB}/mymath_pybind11/bin:${BLIB}/mymath_swig/bin"
%pytest
popd >/dev/null
%endif


%files -n python3-cmake-build-extension -f %{pyproject_files}


%files -n python3-cmake-build-extension-doc
%doc README.md
%doc example/


%changelog
* Fri Jul 19 2024 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 0.6.0-1
- initial build
